# Circular genome tools (cgt)
[![](https://img.shields.io/pypi/v/cgt.svg)](https://pypi.org/project/cgt/) [![](https://github.com/js51/Circular-genome-tools/actions/workflows/python-publish.yml/badge.svg)](https://github.com/js51/Circular-genome-tools/actions/workflows/python-publish.yml)

A sage package for working with circular genomes represented by signed or unsigned permutations. It includes tools for converting between representations as well as visualisations using matplotlib.

To install and use this package, paste the following command in your terminal

`sage -pip install cgt`

and use `import cgt` in a sage script or environment.

If you would like to contribute to `cgt`, please see [`CONTRIBUTING.md`](CONTRIBUTING.md) for how to get set up.

If you use this software in your work, please cite it use the citation function on the github page or see [`CITATION.cff`](CITATION.cff)

**Note:** you will need to at least have Sage version 9.0 installed, and have the GAP package `repsn` installed for the copy of GAP that sits inside Sage. If you aren't sure how to do this, see the installation instructions in [`INSTALL.md`](INSTALL.md).
